### 11. Events and Extending Schema.org

One kind of property we would like to add to a landmark or building are the 
events related to the building. In this case the cornerstone was laid in 1922 
and the tower dedicated on November 11, 1949. Other buildings could have dates
they were designed or dates of renovations, derived from the drawings and 
project records. Museums
may be interested in various events in the history of a painting including
provenance and restorations. History museums and historical societies may also
want to refer to various historical events that relate to their exhibits. Each
of these may also want to promote various events happening in the future like
movie screenings, limited time exhibits, and tours. So it may be important to be
able to disambiguate whether an event is in the future or
of some historical significance.

Schema.org has an Event type defined as: "An event happening at a certain time at a 
certain location." That seems broad enough to apply it to either future or 
historic events. But
the message from Google's [support page on Rich Snippets for events](http://support.google.com/webmasters/bin/answer.py?hl=en&answer=164506)
gives more specific guidance:

> The goal of events snippets is to provide users with additional information 
> about specific events not to promote complementary products or services. Event 
> markup can be used to mark up events that occur on specific future dates, 
> such as a musical concert or an art festival.

Google has
a different view of the world than cultural heritage organizations.
Because of the focus on the future, we may not want to try to mark up historic
events, as rich snippets may be unlikely to show up for past events. 

Another option may be to use the Schema.org [Extension Mechanism](http://schema.org/docs/extension.html)
to possibly make it clearer to the search engines that certain types of events 
are different. 
As Schema.org is intended as a Web-scale schema, there is no possibility of 
having it fit every kind of data on the web.
The basic mechanism for extending an item type is to take any Schema.org type 
URL, add a forward slash to 
the end, and then add the camel cased name of the extension. So one possibility
to handle historic events would be to extend Event:

    http://schema.org/Event/HistoricEvent

At least the search engines will
understand that these items are some type of event. If enough other folks use the 
same extension and the search engines notice, then the search engines may start
using the data in a meaningful way. There is no public formal [process](http://www.w3.org/wiki/SchemaDotOrgProcess) 
for how this might work.
There is still work to be done to have a clear central location to share 
extensions or have a community process to work out new extensions.

The Schema.org extension mechanism has been [controversial](YKK). It causes
some [problems in serializing Microdata to RDF](YKK).
Google does not
follow these rules when creating its own extension of Schema.org for
[software applications](http://support.google.com/webmasters/bin/answer.py?hl=en&answer=1645432).

#### Another way forward

This is just one of the ways in which Schema.org may not fit the needs of 
cultural heritage organizations very well. Other communities have already voiced
their concerns that their domains are not adequately specified. 

For instance,
the [rNews standard](http://dev.iptc.org/rNews) 
of the International Press and Telecommunications Council
was [added to schema.org](http://www.iptc.org/site/Home/Media_Releases/schema.org_adopts_IPTC's_rNews_for_news_markup). 
This was the first industry organization to 
work with the Schema.org partners to publish an expansion of
Schema.org to make it more robust and useful in a particular domain. The 
adoption of much of rNews has resulted in
news and publishing-related types being more expressive and better meeting the needs of 
news organizations.

Another change to the schema was the result of a [collaboration](http://www.whitehouse.gov/blog/2011/11/07/open-innovation-heroes-introducing-veterans-job-bank) 
between schema.org
and the United States Office of Science and Technology Policy to 
[add support for job postings](http://blog.schema.org/2011/11/schemaorg-support-for-job-postings.html) 
to schema.org. One immediate use this was put to was to create a
[job search widget](https://www.nationalresourcedirectory.gov/home/job_search_widget) 
for use on government web sites to highlight job listings from 
employers who commit to hiring veterans. 
(See the [Veterans Job Bank](https://www.nationalresourcedirectory.gov/jobSearch/index).)

So this kind of partnership with domain experts seems like a clear way forward
for other groups.
Libraries, museums, archives, and other cultural heritage organizations could 
start to enumerate the places where the vocabulary could be modified to better
fit their data.
There has been some suggestion for [future discussions with the cultural sector](http://www.w3.org/wiki/WebSchemas#Proposals_from_and_for_Schema.org) 
to this end.


Some of this work may already be available.
Work is ongoing to map other vocabularies to Schema.org. 
This provides a simpler way for organizations to expose their data through 
Microdata and Schema.org while still maintaining their data in their current
schema.
The Dublin Core Metadata Initiative
has begun an effort to do such a mapping. In each of these mappings there are 
certainly some areas where there is not overlap, so there is potential for 
expanding Schema.org in those directions. 

Go to the [next step](/steps/12.html).





