### 2. Adding ItemPage

Again the page above should look exactly the same as the previous step. We will
explore now what microdata has been added to the page.

When using the schema.org vocabularies, every page is implicitly assumed to be 
some kind of [WebPage](http://schema.org/WebPage), but the advice is to 
explicitly declare the type of page. One of the main uses of defining a WebPage
is to specify values for a `breadcrumb` property.

For a show view of a single photograph it seems appropriate to use [ItemPage](http://schema.org/ItemPage).
ItemPage
adds no new properties to WebPage, but it communicates to the search engines that
the page refers to a single item rather than a search results page.
"A page devoted to a single item, such as a particular product or hotel."
I have no proof for this yet, but the assumption is that assigning an `itemtype`
of ItemPage gives the search engines an extra hint that the page should be
indexed as opposed to a SearchResultsPage which may only get crawled.

Further, Ian Hickson the editor of the Microdata specification, has said that
Microdata items exist "in the context of a page and its 
DOM. It does not have an independent existence outside the page." 
([Ian Hickson on public-vocabs list](http://lists.w3.org/Archives/Public/public-html-data-tf/2011Oct/0140.html).)
This is different than the way RDFa may think about embedded structured data in 
HTML. Microdata isn't
so much linked data as it is a description of a single page. 

Currently, there are no properties for the ItemPage.
You can use the inspector in your browser to search for `itemtype` and `itemscope`
and see that we've applied it here to the `body` element.

There is some uncertainty as to where one should place the `itemtype` 
attribute for an ItemPage. Should it be applied to the `html` element or the 
`body`? In some cases placing Microdata markup in the `head` can lead to problems
with [not being able to nest `meta` elements](http://lists.w3.org/Archives/Public/public-html/2011Dec/0188.html).

Below we begin to see that some microdata is able to be extracted from this page. 
This display uses the [MicrodataJS library](https://gitorious.org/microdatajs/) 
created by [Philip Jägenstedt](http://blog.foolip.org/). 
This same library powers [Live Microdata](http://foolip.org/microdatajs/live/)
which is a great tool for testing snippets of HTML with microdata. MicrodataJS
library is actually a javascript implementation of the [Microdata DOM API](http://www.whatwg.org/specs/web-apps/current-work/multipage/microdata.html#microdata-dom-api).
Microdata was created to be easily parsed with simple rules into a JSON serialization.

Because of this built-in serialization to JSON, some desired changes to the 
microdata spec, like [specifying the language of a value](https://www.w3.org/Bugs/Public/show_bug.cgi?id=14470), 
are not impossible, but are more difficult. So this interface may have its 
downsides as well.

You can test whether your browser implements the Microdata DOM API by running the
[microdata test suite](http://w3c-test.org/html/tests/submission/Opera/microdata/001.html) 
created by Opera. 

One of the interesting features of the Microdata specification for developers
is this API. If
you open this page up in [Opera Next](http://www.opera.com/browser/next/) 
(at the time of this writing version 12.00 alpha, build 1191), go to this page,
and open up the console (Ctrl+Shift+i), you can play with the Microdata
DOM API a bit. 
`document.getItems()` will return a NodeList of all items. There is (and will be)
only one top-level item on this page, so the NodeList will contain only one
element. It is possible to get all items of a particular type by specifying the
type or types as an argument like `document.getItems('http://schema.org/ItemPage')`.
This API may change in the future 
["to match what actually gets implemented"](http://old.nabble.com/Re%3A-New-feature-announcement---Implement-HTML5-Microdata-in-WebKit-p32521849.html).


    >>> var itemPage = document.getItems('http://schema.org/ItemPage')
      undefined
    >>> itemPage
      NodeList [<html itemscope="" itemtype="http://schema.org/ItemPage" lang="en">]
    >>> itemPage[0].properties
      HTMLPropertiesCollection []

There are not any properties yet, so [let's add one](/steps/3.html).




