### 3. Adding properties to ItemPage

One property we can easily add to the ItemPage is the name of the page. We can
apply this for now to the name of the photograph found in the `h2` above the image.
We do this simply by adding the attribute `itemprop` with the value of "name" 
like so `itemprop="name"`.

Another thing that we could mark up now is that the ItemPage has an image. Since
one reason to implement microdata is to possibly trigger Rich Snippets, we want
to make sure to include images in our items when they make sense.

Again there is some confusion over how to apply this markup using schema.org.
An image for a WebPage has two different properties that might be used. 
One is the `image` property and the other the `primaryImageOfPage` property. 
Microdata relies on the specification of the 
[vocabulary used to determine the valid data types](http://www.whatwg.org/specs/web-apps/current-work/multipage/microdata.html#names:-the-itemprop-attribute) 
which can be used for a property. 
In this case `primaryImageOfPage` would require creating a nested item with its 
own properties. For now we will use the simpler `image` property which takes a
URL as its value.

When an `itemprop` is applied, different HTML elements provide their value 
in different ways.
A `span` and most other elements assign value to an `itemprop` using the text 
content of the element. The [Microdata spec lists](http://www.whatwg.org/specs/web-apps/current-work/multipage/microdata.html#values) 
some other elements which take their value from various attributes. Here's a simple
table of elements with the first matching one being the property value that gets
assigned.

<table>
  <tr>
    <th>If the element</th>
    <th>value from</th>
  </tr>
  <tr>
    <td>has an <code>itemscope</code></td>
    <td>the resulting nested item</td>
  </tr>
  <tr>
    <td><code>meta</code></td>
    <td><code>content</code> attribute</td>
  </tr>
  <tr>
    <td><code>audio</code>, <code>embed</code>, <code>iframe</code>, <code>img</code>, 
      <code>source</code>, <code>track</code>, or <code>video</code></td>
    <td>absolute URL of <code>src</code> attribute</td>
  </tr>
  <tr>
    <td><code>a</code>, <code>area</code>, or <code>link</code></td>
    <td>absolute URL of <code>href</code> attribute</td>
  </tr>
  
  <tr>
    <td><code>object</code></td>
    <td>absolute URL of <code>data</code> attribute</td>
  </tr>
  
  <tr>
    <td><code>data</code></td>
    <td><code>value</code> attribute</td>
  </tr>
  
  <tr>
    <td><code>meta</code></td>
    <td><code>content</code> attribute</td>
  </tr>
  
  <tr>
    <td><code>time</code></td>
    <td>the element's datetime value</td>
  </tr>
  
  <tr>
    <td>all other elements</td>
    <td>text content</td>
  </tr>
  
</table>

Some of these elements like `data` and `time` are new HTML5 elements.  
The `link` element can now be used [within the body of HTML](http://www.whatwg.org/specs/web-apps/current-work/multipage/semantics.html#the-link-element),
meaning it can be more widely used.

Just using an `itemtype` is not enough to trigger any kind of Rich Snippet or
give the search engines enough of a hint what the content means, so 
[let's add a property](/steps/4.html).

