### 5. Adding a `Photograph` item and nesting

Looking at the hierarchy of all schema types, we definitely
want to describe that the page is `about` a [Photograph](http://schema.org/Photograph).

The schema.org vocabulary often expects the value of a particular property to be 
an item itself.
This means that on the same element that has the `itemprop` there would also
be `itemscope` and `itemtype` attributes, which would contain its own properties.

In our case the `div#metadata` already has an `itemprop="about"` and adding in
`itemscope` and `itemtype` results in:

    <div id="metadata" itemprop="about" itemscope itemtype="http://schema.org/Photograph">
      
Again, this translates to: the `ItemPage` is `about` a `Photograph`. 
This nests the `Photograph` within the `ItemPage`. You can have any number of
levels deep, as we will see soon as another level is added within the `Photograph`.

Whether to nest or not is a common question about applying Microdata. 
Currently, the Google Rich
Snippets testing tool only knows about certain item types and for those sometimes
only displays possible rich snippets when the recognized item is [not nested](http://lists.w3.org/Archives/Public/public-vocabs/2011Nov/0073.html) 
or [nested under certain types](http://lists.w3.org/Archives/Public/public-vocabs/2011Nov/0082.html).

So far the `Photograph` includes no properties, so let's add some now. Within the
[Photograph Information](#item) section of the page, there is some good fielded
metadata we are already using to describe the photograph. 

The "Subjects" here map well enough to the `keywords` property of `Photograph`.
In this case we could put the `itemprop="keywords"` attribute on the `dd` 
element, which
surrounds all of the text of keywords. The microdata processor would then return
all of the text content within the `dd` including any line breaks. A consumer 
of the microdata could then split it up however it wants.

The subjects here contain one "keyword" of multiple words 
("Universities and colleges"), so we may want to 
make sure that each continues to be a single "keyword" and not just split on spaces
by a consumer. So in this case `itemprop="keywords"` is repeated for each of 
the subjects. The expected value of the `keyword` property for a `Photograph`
is text. If this was applied to an `a` containing a subject, then the value
returned would be the value of the `href` attribute--a URL (check back to the 
previous chart). To have a text
value returned instead, we include a `span` element within each `a` and apply the
`itemprop` there. You can see in the microdata JSON output below that this 
causes the `keywords` to be an array.

So one question to ask is what the difference is between marking up keywords
on the page in this way versus how it can be done in the `head` of the page.
Don't search engines ignore the keywords in the head of the page?
Search engines caught on that the keywords placed in the `head` of the page 
were often placed there to try to game the system and rank for terms the page
may not have even been about. Marking up the visible content of the page
as we are doing with microdata, means
that users will see these keywords, so may be more likely to really describe
the content of the page. Search engines therefore may pay more attention to these
keywords than to some hidden keywords in the `head` of the document.
Google advises page authors to not mark up [non-visible content](http://support.google.com/webmasters/bin/answer.py?hl=en&answer=176035)
on the page, but to stick to adding microdata attributes to what is visible to 
users. Later we will see how
there are some occassions when it is necessary or convenient to add hidden 
markup to add data.

There is some confusion about singulars and plurals in schema.org. Related
to the plurals problem is whether properties are intended to be repeated or not.
It is valid microdata to do it either way, but the vocabulary could specify a
preference. It may be in the future that properties given as plurals expect to
have multiple values, but for now 
[even singular properties can have multiple values](http://www.w3.org/2011/webschema/track/issues/5).

We also add `genre` for the genres within the "Photograph Information" section
of the page as well.

Since this is a photograph, we'll want to add the image on the page as the
`image` property to the `Photograph`. The only problem is that because of the
layout and grid system used, the image is not nested within the `div` which
holds the `Photograph`. So as you see below, there is no image associated with
the `Photograph`.
The [next page](/steps/6.html) will reveal the solution 
for this problem.