### 6. `itemref`

> Valid HTML is particularly important in pages that contain embedded markup. 
> All methods of embedding data within HTML use the structure of the HTML to 
> determine the meaning of the additional markup. [http://www.w3.org/wiki/Choosing_an_HTML_Data_Format#Good_Publishing_Practice](http://www.w3.org/wiki/Choosing_an_HTML_Data_Format#Good_Publishing_Practice)

While we have the content on our page relatively well organized to contain our
items, our layout and grid system mean that the image of the photograph is
not nested within the same `div` as the metadata about the photograph. When
coding new pages it is important to think not just about presentation but also
about how to structure the page with [both presentation and data in mind](http://semanticweb.com/schema-org-microdata-rdfa-and-black-friday-at-bestbuy_b24643). 
It makes marking up data easier if the 
properties of a thing are grouped together.

While in most
cases it will be easier to arrange our markup so that the properties of an
item are all within the same block on the page, microdata provides a rather
simple mechanism for including properties that are outside of that scope.

Microdata uses the `itemref` attribute to make this more convenient.

> Note: The itemref attribute is not part of the microdata data model. It is merely a 
> syntactic construct to aid authors in adding annotations to pages where the 
> data to be annotated does not follow a convenient tree structure.
> [Microdata specification itemref attribute](http://www.whatwg.org/specs/web-apps/current-work/multipage/microdata.html#attr-itemref)

Here's a simple non-Schema.org Microdata example of a graphicElement item 
referring to an `img` outside
of its scope in the DOM. 
To include the image source URL to describe the graphicElement,
the `itemref` attribute is placed on the same element as the `itemscope` and
`itemtype`. The `itemref` has as a value a space separated list `id`s of other 
elements. (YKK use schema.org instead?)

    <img src="http://code4lib.org/files/logo.png" id="logo" itemprop="image">
    <div itemscope itemtype="http://md.example.org/graphicElement" itemref="logo">
      <span itemprop="name">Code4Lib Logo</span>      
    </div>
    
This snippet would return the following microdata as JSON:

    {
      "items": [
        {
          "type": [
            "http://md.example.org/graphicElement"
          ],
          "properties": {
            "image": [
              "http://code4lib.org/files/logo.png"
            ],
            "name": [
              "Code4Lib Logo"
            ]
          }
        }
      ]
    }
    
In our example above we already have an `id` of main_image_and an `itemprop` with 
the value "image" on the image. All that we need to do in this step is add
`itemref="main_image"` to `div#metadata`.

Go on to the [next step](/steps/7.html).
