### 7. `time` and Datatypes

One piece of data that would be good to add to to the Photograph in some way 
is the created date. Looking at the properties available for a [`Photograph`](http://schema.org/Photograph),
the date displayed most closely matches the `dateCreated` property with an 
expected value of [`Date`](http://schema.org/Date). 

The Microdata specification does not provide a mechanism for specifying data 
types. RDF, and so RDFa, has the ability to specify [datatypes](http://www.w3.org/TR/2011/WD-rdfa-core-20111215/#typed-literals)
identified through URI references, usually using those defined in 
the [XML Schema Datatypes specification](http://www.w3.org/TR/2004/REC-xmlschema-2-20041028/).
RDFa itself defines only the XMLLiteral datatype.
This allows for the expected values in RDFa to be strongly typed in a way that 
Microdata does not have available to it.

Instead Microdata again [relies on a vocabulary](http://www.whatwg.org/specs/web-apps/current-work/multipage/microdata.html#names:-the-itemprop-attribute)
to define expected data types. 
Schema.org has four basic types: Boolean, Date, Number, and Text, but none of 
them are very well documented.

HTML5 has some new ways to include machine-readable data in HTML and these can 
be used for the Schema.org datatypes and are among the few elements which can
require typed data. 
The [`time`](http://www.whatwg.org/specs/web-apps/current-work/multipage/text-level-semantics.html#the-time-element) 
and [`data`](http://www.whatwg.org/specs/web-apps/current-work/multipage/text-level-semantics.html#the-data-element)
elements were added to HTML5.
In the Fall of 2011, though,
there was some churn with these two elements. First, `time` was removed to be
replaced with the more generic `data` element
(with some [strong objections](http://www.brucelawson.co.uk/2011/goodbye-html5-time-hello-data/)).
It was then reinstated (with [some drama](https://plus.google.com/107429617152575897589/posts/3ZEQAVkF6xd).

So while `time` is in the specification again, the Schema.org documentation 
adds its own confusion
to the matter, by using the `meta` element instead when it needs a date. 
In its own tutorials Google follows the pattern of using `meta` whenever the 
data for machines is
different than what is displayed to humans on the page.
An
[`Event`](http://schema.org/Event), for instance, can have a `startDate` which
is written like this:

    <meta itemprop="startDate" content="2016-04-21T20:00">
      Thu, 04/21/16
      8:00 p.m.
      
Using the `meta` and `link` elements within the `body` body of a document is 
[allowed in HTML5 when used with an `itemprop` attribute](http://www.whatwg.org/specs/web-apps/current-work/multipage/elements.html#flow-content). 
These
can sometimes be useful for Microdata in expressing the meaning of content or
a URL which has no
usefulness to a human reader. 
The `meta` element here is used to give the machine readable date near the date
visible to the user. It is hidden on the page, so goes against the general 
recommendation to not use hidden markup for Microdata. 
Further, the `meta` element does not even surround the free text version of the 
date disassociating them from each other.  

You could alternatively mark up the same text with `<time>` like so:
  
    <time itemprop="startDate" datetime="2016-04-21T20:00">
      Thu, 04/21/16
      8:00 p.m.
    </time>
    
The `time` element has the correct semantics for these examples.
For our Photograph, I have chosen to use the `time` element, to mark up the 
created Date like so:

    <time itemprop="dateCreated" datetime="1981">
      circa 1981
    </time>
    
I have made no attempt yet to handle the approximate date ("circa"), though,
this is certainly one use case for what a time 
element needs. Also the MicrodataJS parser in use on this site erroneously takes 
the text value of the `time` element rather than the value of the `@datetime` 
attribute. As `time` is currently specified, the value for purposes of Microdata
of `time` is only falls back to the text content if there is no `@datetime` 
attribute.
Up until some time in December of 2011 the Google Rich Snippets Testing Tool, 
was throwing a warning that just a year was not a valid ISO8601 date,
[though it seems to be](http://en.wikipedia.org/wiki/ISO_8601#Years). The
HTML5 specification has [stricter processing rules](http://www.whatwg.org/specs/web-apps/current-work/multipage/common-microsyntaxes.html#vaguer-moments-in-time). 

As dates and [ambiguity about dates](http://wiki.whatwg.org/wiki/Time_element#Fuzzy_dates) 
is important for describing cultural heritage 
materials, hopefully the HTML5 processing rules can be adjusted to handle all
valid ISO8601 dates. It seems as if the WHATWG has accepted a proposal to
support [year only dates](http://wiki.whatwg.org/wiki/Time_element#year_only).

The next step will add [information about the pictured building](/steps/8.html).

